Changelog
==========

0.7.0
------

- Add filters and displays to Django model Admin
- Support Django 1.8, compatible with both django-south (django < 1.7) and built-in schema migration (django >= 1.7)
- Compatible with Python 3
- Test fixtures, and integrated with travis-ci

0.6.2
------

- Fix README.rst reStructuredText syntax format
- Use relative imports
- Add contributors to AUTHORS.txt

0.6.1
------

- Add support for custom user model
- mark_as_unread
- Require django-model-utils >= 2.0.3
- Use different `now` function according to the `USE_TZ` setting

0.6.0
------

- Improve documentation
- Add unicode support at admin panel or shell

0.5.5
------

Support for arbitrary data attribute.

0.5.1
-----

Fix package descriptions and doc links.

0.5
-----

First version based on `django-activity-stream <https://github.com/justquick/django-activity-stream>`_ v0.4.3

